@@ -6,6 +6,11 @@ use warnings;
 sub new {
   my $class = shift;
   my $self  = bless {}, $class;
+  $self->set_options(@_) if @_;
+
+  if (!$self->can('log')) {
+    require Log::Dump; Log::Dump->import;
+  }
 
   $self;
 }
@@ -15,10 +20,6 @@ sub set_options {
 
   %{ $self } = @_;
 
-  if (!$self->can('log')) {
-    require Log::Dump; Log::Dump->import;
-  }
-
   if ($self->can('logger')) {
     $self->logger( $self->{verbose} || $self->{debug} || $self->{logfilter} ? 1 : 0 );
   }
@@ -27,6 +28,8 @@ sub set_options {
     push @filters, '!debug' unless $self->{debug};
     $self->logfilter(@filters);
   }
+
+  $self;
 }
 
 sub options {}
@@ -189,7 +192,7 @@ loads L<CLI::Dispatch> to dispatch directly back to the command. This is handy i
 
 =head2 new
 
-creates a command object.
+creates a command object. It may take a hash of options.
 
 =head2 set_options
 
