@@ -5,6 +5,7 @@ use warnings;
 use Test::Classy::Base;
 use CLI::Dispatch;
 use File::Spec;
+use Try::Tiny;
 
 sub list : Tests(5) {
   my $class = shift;
@@ -79,11 +80,12 @@ sub dispatch {
   my $stdout = select($null);
 
   my $ret;
-  eval { $ret = CLI::Dispatch->run('CLIDTest::Check') };
+  try   { $ret = CLI::Dispatch->run('CLIDTest::Check') }
+  catch { $ret = $_ || 'Obscure error' };
 
   select($stdout);
 
-  return $@ ? $@ : $ret;
+  return $ret;
 }
 
 1;
